The Units System
================

Most of these functions can be acccessed directly from Solcore::

    >>> from solcore import eV

    >>> print(eV(1e-19))
    0.624 eV

.. automodule:: solcore.units_system.units_system
    :members:
    :undoc-members:
